# MindPype

MindPype is a Python-based software library that enables rapid prototyping, development, and implementation of BCI processing pipelines. [Learn more about the library here.](https://nivanov94.github.io/bcipy/index.html)
